package com.ruoyi.ems.base.domain;

import java.math.BigDecimal;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

/**
 * 计量设备阈值维护对象 ems_base_monitor_threshold
 *
 * @author Yinq
 * @date 2024-07-09
 */
public class EmsBaseMonitorThreshold extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 主键标识
     */
    private Long objId;

    /**
     * 计量设备编号
     */
    @Excel(name = "计量设备编号")
    private String monitorCode;

    /**
     * 计量设备名称
     */
    @Excel(name = "计量设备名称")
    private String monitorName;

    /**
     * 计量设备类型
     */
    @Excel(name = "计量设备类型")
    private Long monitorType;

    /**
     * A相电流最大值
     */
    @Excel(name = "A相电流最大值")
    private BigDecimal iAMax;

    /**
     * A相电流最小值
     */
    @Excel(name = "A相电流最小值")
    private BigDecimal iAMin;

    /**
     * B相电流最大值
     */
    @Excel(name = "B相电流最大值")
    private BigDecimal iBMax;

    /**
     * B相电流最小值
     */
    @Excel(name = "B相电流最小值")
    private BigDecimal iBMin;

    /**
     * C相电流最大值
     */
    @Excel(name = "C相电流最大值")
    private BigDecimal iCMax;

    /**
     * C相电流最小值
     */
    @Excel(name = "C相电流最小值")
    private BigDecimal iCMin;

    /**
     * A相电压最大值
     */
    @Excel(name = "A相电压最大值")
    private BigDecimal vAMax;

    /**
     * A相电压最小值
     */
    @Excel(name = "A相电压最小值")
    private BigDecimal vAMin;

    /**
     * B相电压最大值
     */
    @Excel(name = "B相电压最大值")
    private BigDecimal vBMax;

    /**
     * B相电压最小值
     */
    @Excel(name = "B相电压最小值")
    private BigDecimal vBMin;

    /**
     * C相电压最大值
     */
    @Excel(name = "C相电压最大值")
    private BigDecimal vCMax;

    /**
     * C相电压最小值
     */
    @Excel(name = "C相电压最小值")
    private BigDecimal vCMin;

    /**
     * 小时耗量
     */
    @Excel(name = "小时耗量")
    private BigDecimal hourConsumption;

    /**
     * 天耗量
     */
    @Excel(name = "天耗量")
    private BigDecimal dayConsumption;

    /**
     * 线损率(%)
     */
    @Excel(name = "线损率(%)")
    private BigDecimal lineLossRate;

    /**
     * 启用标识
     */
    @Excel(name = "启用标识")
    private String isFlag;

    public String getMonitorName() {
        return monitorName;
    }

    public void setMonitorName(String monitorName) {
        this.monitorName = monitorName;
    }

    public void setObjId(Long objId) {
        this.objId = objId;
    }

    public Long getObjId() {
        return objId;
    }

    public void setMonitorCode(String monitorCode) {
        this.monitorCode = monitorCode;
    }

    public String getMonitorCode() {
        return monitorCode;
    }

    public void setMonitorType(Long monitorType) {
        this.monitorType = monitorType;
    }

    public Long getMonitorType() {
        return monitorType;
    }

    public void setiAMax(BigDecimal iAMax) {
        this.iAMax = iAMax;
    }

    public BigDecimal getiAMax() {
        return iAMax;
    }

    public void setiAMin(BigDecimal iAMin) {
        this.iAMin = iAMin;
    }

    public BigDecimal getiAMin() {
        return iAMin;
    }

    public void setiBMax(BigDecimal iBMax) {
        this.iBMax = iBMax;
    }

    public BigDecimal getiBMax() {
        return iBMax;
    }

    public void setiBMin(BigDecimal iBMin) {
        this.iBMin = iBMin;
    }

    public BigDecimal getiBMin() {
        return iBMin;
    }

    public void setiCMax(BigDecimal iCMax) {
        this.iCMax = iCMax;
    }

    public BigDecimal getiCMax() {
        return iCMax;
    }

    public void setiCMin(BigDecimal iCMin) {
        this.iCMin = iCMin;
    }

    public BigDecimal getiCMin() {
        return iCMin;
    }

    public void setvAMax(BigDecimal vAMax) {
        this.vAMax = vAMax;
    }

    public BigDecimal getvAMax() {
        return vAMax;
    }

    public void setvAMin(BigDecimal vAMin) {
        this.vAMin = vAMin;
    }

    public BigDecimal getvAMin() {
        return vAMin;
    }

    public void setvBMax(BigDecimal vBMax) {
        this.vBMax = vBMax;
    }

    public BigDecimal getvBMax() {
        return vBMax;
    }

    public void setvBMin(BigDecimal vBMin) {
        this.vBMin = vBMin;
    }

    public BigDecimal getvBMin() {
        return vBMin;
    }

    public void setvCMax(BigDecimal vCMax) {
        this.vCMax = vCMax;
    }

    public BigDecimal getvCMax() {
        return vCMax;
    }

    public void setvCMin(BigDecimal vCMin) {
        this.vCMin = vCMin;
    }

    public BigDecimal getvCMin() {
        return vCMin;
    }

    public void setHourConsumption(BigDecimal hourConsumption) {
        this.hourConsumption = hourConsumption;
    }

    public BigDecimal getHourConsumption() {
        return hourConsumption;
    }

    public void setDayConsumption(BigDecimal dayConsumption) {
        this.dayConsumption = dayConsumption;
    }

    public BigDecimal getDayConsumption() {
        return dayConsumption;
    }

    public void setLineLossRate(BigDecimal lineLossRate) {
        this.lineLossRate = lineLossRate;
    }

    public BigDecimal getLineLossRate() {
        return lineLossRate;
    }

    public void setIsFlag(String isFlag) {
        this.isFlag = isFlag;
    }

    public String getIsFlag() {
        return isFlag;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("objId", getObjId())
                .append("monitorCode", getMonitorCode())
                .append("monitorType", getMonitorType())
                .append("iAMax", getiAMax())
                .append("iAMin", getiAMin())
                .append("iBMax", getiBMax())
                .append("iBMin", getiBMin())
                .append("iCMax", getiCMax())
                .append("iCMin", getiCMin())
                .append("vAMax", getvAMax())
                .append("vAMin", getvAMin())
                .append("vBMax", getvBMax())
                .append("vBMin", getvBMin())
                .append("vCMax", getvCMax())
                .append("vCMin", getvCMin())
                .append("hourConsumption", getHourConsumption())
                .append("dayConsumption", getDayConsumption())
                .append("lineLossRate", getLineLossRate())
                .append("isFlag", getIsFlag())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .toString();
    }
}
